@@ -123,6 +123,13 @@ class RyuApp(object):
         for observer in self.get_observers(ev, state):
             self.send_event(observer, ev)
 
+    def reply_to_request(self, req, rep):
+        rep.dst = req.src
+        if req.sync:
+            self.send_reply(rep)
+        else:
+            self.send_event(rep.dst, rep)
+
     def close(self):
         """
         teardown method.
@@ -198,27 +205,28 @@ class AppManager(object):
             register_app(app)
             self.applications[app_name] = app
 
-        for key, i in SERVICE_BRICKS.items():
+        for i in SERVICE_BRICKS.values():
             for _k, m in inspect.getmembers(i, inspect.ismethod):
-                if hasattr(m, 'observer'):
-                    # name is module name of ev_cls
-                    name = m.observer.split('.')[-1]
-                    if name in SERVICE_BRICKS:
-                        brick = SERVICE_BRICKS[name]
-                        brick.register_observer(m.ev_cls, i.name,
-                                                m.dispatchers)
+                if not hasattr(m, 'observer'):
+                    continue
+
+                # name is module name of ev_cls
+                name = m.observer.split('.')[-1]
+                if name in SERVICE_BRICKS:
+                    brick = SERVICE_BRICKS[name]
+                    brick.register_observer(m.ev_cls, i.name, m.dispatchers)
 
                 # allow RyuApp and Event class are in different module
-                if hasattr(m, 'ev_cls'):
-                    for brick in SERVICE_BRICKS.itervalues():
-                        if m.ev_cls in brick._EVENTS:
-                            brick.register_observer(m.ev_cls, i.name)
+                for brick in SERVICE_BRICKS.itervalues():
+                    if m.ev_cls in brick._EVENTS:
+                        brick.register_observer(m.ev_cls, i.name,
+                                                m.dispatchers)
 
         for brick, i in SERVICE_BRICKS.items():
             LOG.debug("BRICK %s" % brick)
             for ev_cls, list in i.observers.items():
                 LOG.debug("  PROVIDES %s TO %s" % (ev_cls.__name__, list))
-            for ev_cls, handler in i.event_handlers.items():
+            for ev_cls in i.event_handlers.keys():
                 LOG.debug("  CONSUMES %s" % (ev_cls.__name__,))
 
     def close(self):
